 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 Reahl-workstation contains a few utilities that helps to have available
 on a developer workstation.
